# Choose the version matching your Elasticsearch cluster:
# smf-mcp[elasticsearch7]>={version}  # For Elasticsearch 7.x
# smf-mcp[elasticsearch8]>={version}  # For Elasticsearch 8.x
# smf-mcp[elasticsearch9]>={version}  # For Elasticsearch 9.x
smf-mcp[elasticsearch9]>={version}
